%
% Root system analysis: root surface densities in REVs root length
% fractions versus depth.
% 
% See also: getDensity, Example_Maize
%
% Copyright 2008-2013 Daniel Leitner. See license.txt for details.
% 
clear all;
set(0,'RecursionLimit',10000);

% root architecture defition (same as Example_Maize)
p{1}.r = [2,0.2];
p{1}.lb = [0.7,0.07];          
p{1}.la = [7.7,1.57];                    
p{1}.ln = [0.7,0.07];                 
p{1}.nob = [50,5];  
p{1}.a = 0.03*2;   
p{1}.theta = 0;
p{1}.color = [55/255,50/255,25/255];
p{1}.tropism = [1,2,15*pi/180]; 
p{1}.dx= 0.25; 
p{1}.successor = [2,1];
p{2}.r = [6.4, 0.64];
p{2}.lb = [0.7, 0.07];    
p{2}.la = [2.7, 0.27];                       
p{2}.ln = [0.7, 0.07];               
p{2}.nob = [7, 0.7];                  
p{2}.a = 0.02*2;                
p{2}.theta = [63*pi/180,0];      
p{2}.color = [125/255,150/255,120/255];
p{2}.tropism = [1,0.5,20*pi/180]; 
p{2}.dx= 0.2;
p{2}.successor = [3,1];
p{3}.r  = [1.5,0.15];                                        
p{3}.la  = [0.2,0.02];                    
p{3}.a  = 0.01*2;                                 
p{3}.theta = [68*pi/180,3*pi/180];        
p{3}.color = [160/255,150/255,130/255];
p{3}.tropism = [1,0,20*pi/180];
p{3}.dx= 0.2;
p = completeParameters(p);

% Simulate
n0=5; % tap roots
r0=5; % cm
simtime = 30; % days
root = createRootSystem(0,0,2*rand(n0,1),zeros(7,1),r0);
tic 
str = applyRules(root,simtime); % takes some time...
toc    

%
bnd = getBounds(str);

% plot root system (surface densities in y-z plane)
figure
plotTubes(str); hold on;
X = linspace(bnd(1),bnd(2),3); 
Y = linspace(bnd(3),bnd(4),10);
Z = linspace(bnd(5),bnd(6),20);
m = getDensity(str,X,Y,Z,'s');
m = permute(m,[2,1,3]);
slice(0.5*(X(1:end-1)+X(2:end)),0.5*(Y(1:end-1)+Y(2:end)),0.5*(Z(1:end-1)+Z(2:end)),m,[0],[],[]);
light, view(70,30);

% plot root system (surface densities in x-y plane)
figure
plotTubes(str); hold on;
X = linspace(bnd(1),bnd(2),10); 
m = getDensity(str,X,Y,Z,'s');
m = permute(m,[2,1,3]);
slice(0.5*(X(1:end-1)+X(2:end)),0.5*(Y(1:end-1)+Y(2:end)),0.5*(Z(1:end-1)+Z(2:end)),m,[],[],[-15]);
light, view(37.5,30);

% root length fraction / depth
X = [-inf inf];
Y = [-inf inf];
Z = linspace(bnd(5),bnd(6),20);
[map,l] = getDensity(str,X,Y,Z,'l');
d = 1:size(map,3);
d(:) = map(1,1,:);
figure;
plot(d/l,Z(1:length(d)));
title('Root length distribution')
ylabel('depth (cm)');
xlabel('root length fraction');
