function rootsystem = createDicotRS(depth,first,delay,maxB,dz)
% createRootSystem: creates multiple taproots 
%
% Parameters:
% depth             planting depth (cm)
% first             first basal roots [mean, sd] (days)
% delay             time delay between basal roots [mean, sd] (days)
% maxB               maximal number of basal roots
% dz                distance upwards the hypocotyl per basal root [mean,
%                   sd] (cm) 
%
% There is a limitation of maximal 100 basal roots.
%
% rootsystem     initial l-system string of the root system
%
% See also: completeParameters, applyRules.
%
% Copyright 2015 Daniel Leitner & Andrea Schnepf. See license.txt for details.
%     

global parameters;

if isempty(parameters)
    error('createRootSystems: parameters not set use completeParameters to set global parameters');
end

if nargin<5
    dz = [0.1, 0]; % cm
end

% add a zero to all inputs
first = [first,0];
delay = [delay,0];
dz = [dz,0];

%
% set up one 0-order root 
%
taproot = letter(303,1); % create tap root
basal = letter(303,4); % create basal root
push = letter('[');
pop = letter(']');
pitchdown  = letter('^',pi/2);
turnaround = letter('|');

%
% set up tap and basal roots
%
N = (365-first(1))/delay(1);
N = min(N,maxB); % limit to maxB basalroots
ct = first(1)+randn()*first(2);
cz = 0;
node = [push; taproot; pop];
for i = 1 : N
    cz = cz+dz(1)+randn()*dz(2);
    fup = letter('f',cz);  % we could move up the hypocotyl
    ct = ct + delay(1)+randn()*delay(2);
    root = letter(301,[0 ct],basal); % delay
    node = [node; push; turnaround; fup; turnaround; root; pop]; % z position of primaries
end

%
% set up root system
% 
rootsystem = [pitchdown;letter('f',depth);node];   
rootsystem = updatePos(rootsystem);

